@@ -124,7 +124,7 @@ joinpath(char *buf, size_t bufsiz, const char *path, const char *path2)
 
 	r = snprintf(buf, bufsiz, "%s%s%s",
 		path, path[0] && path[strlen(path) - 1] != '/' ? "/" : "", path2);
-	if (r == -1 || (size_t)r >= bufsiz)
+	if (r < 0 || (size_t)r >= bufsiz)
 		errx(1, "path truncated: '%s%s%s'",
 			path, path[0] && path[strlen(path) - 1] != '/' ? "/" : "", path2);
 }
@@ -636,9 +636,13 @@ printshowfile(FILE *fp, struct commitinfo *ci)
 		patch = ci->deltas[i]->patch;
 		delta = git_patch_get_delta(patch);
 		/* NOTE: only links to new path */
-		fprintf(fp, "[1|diff --git a/%s b/%s",
-			delta->old_file.path, delta->new_file.path);
-		fprintf(fp, "|%s/file/%s.gph|server|port]\n", relpath, delta->new_file.path);
+		fputs("[1|diff --git a/", fp);
+		gphlink(fp, delta->old_file.path, strlen(delta->old_file.path));
+		fputs(" b/", fp);
+		gphlink(fp, delta->new_file.path, strlen(delta->new_file.path));
+		fprintf(fp, "|%s/file/", relpath);
+		gphlink(fp, delta->new_file.path, strlen(delta->new_file.path));
+		fputs(".gph|server|port]\n", fp);
 
 		/* check binary data */
 		if (delta->flags & GIT_DIFF_FLAG_BINARY) {
@@ -710,7 +714,7 @@ writelog(FILE *fp, const git_oid *oid)
 
 		git_oid_tostr(oidstr, sizeof(oidstr), &id);
 		r = snprintf(path, sizeof(path), "commit/%s.gph", oidstr);
-		if (r == -1 || (size_t)r >= sizeof(path))
+		if (r < 0 || (size_t)r >= sizeof(path))
 			errx(1, "path truncated: 'commit/%s.gph'", oidstr);
 		r = access(path, F_OK);
 
@@ -935,7 +939,7 @@ writefilestree(FILE *fp, git_tree *tree, const char *path)
 
 		r = snprintf(filepath, sizeof(filepath), "file/%s.gph",
 		         entrypath);
-		if (r == -1 || (size_t)r >= sizeof(filepath))
+		if (r < 0 || (size_t)r >= sizeof(filepath))
 			errx(1, "path truncated: 'file/%s.gph'", entrypath);
 
 		if (!git_tree_entry_to_object(&obj, repo, entry)) {
@@ -968,7 +972,8 @@ writefilestree(FILE *fp, git_tree *tree, const char *path)
 				fprintf(fp, "%7dL", lc);
 			else
 				fprintf(fp, "%7juB", (uintmax_t)filesize);
-			fprintf(fp, "|%s/%s", relpath, filepath);
+			fprintf(fp, "|%s/", relpath);
+			gphlink(fp, filepath, strlen(filepath));
 			fputs("|server|port]\n", fp);
 			git_object_free(obj);
 		} else if (!git_submodule_lookup(&module, repo, entryname)) {
